pub struct BootMetadata {
pub zbi_type: Option<u32>,
pub zbi_extra: Option<u32>,
/* private fields */
}Expand description
Device metadata to be passed from bootloader via a ZBI record.
Fields
zbi_type: Option<u32>Metadata type (matches zbi_header_t.type for bootloader metadata).
zbi_extra: Option<u32>Matches zbi_header_t.extra for bootloader metadata.
Used in cases where bootloader provides multiple metadata records of the same type.