pub struct Irq {
pub irq: Option<u32>,
pub mode: Option<ZirconInterruptMode>,
pub properties: Option<Vec<NodeProperty2>>,
pub name: Option<String>,
pub wake_vector: Option<bool>,
/* private fields */
}Fields
irq: Option<u32>mode: Option<ZirconInterruptMode>Bit flag for setting the interrupt mode.
properties: Option<Vec<NodeProperty2>>Properties for this interrupt’s fragment.
name: Option<String>Name that can be used to retrieve the irq using
[fuchsia.hardware.platform.device/GetInterruptByName].
It is valid for this to be empty, however the resource will only be able
to be retrieved using [fuchsia.hardware.platform.device/GetInterruptById].
wake_vector: Option<bool>If set to true, this interrupt will wake the device out of suspend.