pub struct SysSuspendCallbackRequest {
pub enable_wake: bool,
pub suspend_reason: u8,
}Fields
enable_wake: boolsuspend_reason: u8Trait Implementations
Sourceimpl Clone for SysSuspendCallbackRequest
impl Clone for SysSuspendCallbackRequest
Sourcefn clone(&self) -> SysSuspendCallbackRequest
fn clone(&self) -> SysSuspendCallbackRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SysSuspendCallbackRequest
impl Debug for SysSuspendCallbackRequest
Sourceimpl<D: ResourceDialect> Decode<SysSuspendCallbackRequest, D> for SysSuspendCallbackRequest
impl<D: ResourceDialect> Decode<SysSuspendCallbackRequest, D> for SysSuspendCallbackRequest
Sourceimpl<D: ResourceDialect> Encode<SysSuspendCallbackRequest, D> for &SysSuspendCallbackRequest
impl<D: ResourceDialect> Encode<SysSuspendCallbackRequest, D> for &SysSuspendCallbackRequest
Sourceimpl<D: ResourceDialect, T0: Encode<bool, D>, T1: Encode<u8, D>> Encode<SysSuspendCallbackRequest, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<bool, D>, T1: Encode<u8, D>> Encode<SysSuspendCallbackRequest, D> for (T0, T1)
Sourceimpl Hash for SysSuspendCallbackRequest
impl Hash for SysSuspendCallbackRequest
Sourceimpl Ord for SysSuspendCallbackRequest
impl Ord for SysSuspendCallbackRequest
Sourcefn cmp(&self, other: &SysSuspendCallbackRequest) -> Ordering
fn cmp(&self, other: &SysSuspendCallbackRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for SysSuspendCallbackRequest
impl PartialOrd for SysSuspendCallbackRequest
Sourceimpl TypeMarker for SysSuspendCallbackRequest
impl TypeMarker for SysSuspendCallbackRequest
Sourcetype Owned = SysSuspendCallbackRequest
type Owned = SysSuspendCallbackRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SysSuspendCallbackRequest
impl ValueTypeMarker for SysSuspendCallbackRequest
Sourcetype Borrowed<'a> = &'a SysSuspendCallbackRequest
type Borrowed<'a> = &'a SysSuspendCallbackRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for SysSuspendCallbackRequest
impl Eq for SysSuspendCallbackRequest
impl Persistable for SysSuspendCallbackRequest
impl StructuralPartialEq for SysSuspendCallbackRequest