#[repr(C)]pub struct SysSuspendCallbackResponse {
pub out_status: i32,
}Fields
out_status: i32Trait Implementations
Sourceimpl Clone for SysSuspendCallbackResponse
impl Clone for SysSuspendCallbackResponse
Sourcefn clone(&self) -> SysSuspendCallbackResponse
fn clone(&self) -> SysSuspendCallbackResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SysSuspendCallbackResponse
impl Debug for SysSuspendCallbackResponse
Sourceimpl<D: ResourceDialect> Decode<SysSuspendCallbackResponse, D> for SysSuspendCallbackResponse
impl<D: ResourceDialect> Decode<SysSuspendCallbackResponse, D> for SysSuspendCallbackResponse
Sourceimpl<D: ResourceDialect> Encode<SysSuspendCallbackResponse, D> for &SysSuspendCallbackResponse
impl<D: ResourceDialect> Encode<SysSuspendCallbackResponse, D> for &SysSuspendCallbackResponse
Sourceimpl<D: ResourceDialect, T0: Encode<i32, D>> Encode<SysSuspendCallbackResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<i32, D>> Encode<SysSuspendCallbackResponse, D> for (T0,)
Sourceimpl Hash for SysSuspendCallbackResponse
impl Hash for SysSuspendCallbackResponse
Sourceimpl Ord for SysSuspendCallbackResponse
impl Ord for SysSuspendCallbackResponse
Sourcefn cmp(&self, other: &SysSuspendCallbackResponse) -> Ordering
fn cmp(&self, other: &SysSuspendCallbackResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for SysSuspendCallbackResponse
impl PartialOrd for SysSuspendCallbackResponse
Sourceimpl TypeMarker for SysSuspendCallbackResponse
impl TypeMarker for SysSuspendCallbackResponse
Sourcetype Owned = SysSuspendCallbackResponse
type Owned = SysSuspendCallbackResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SysSuspendCallbackResponse
impl ValueTypeMarker for SysSuspendCallbackResponse
Sourcetype Borrowed<'a> = &'a SysSuspendCallbackResponse
type Borrowed<'a> = &'a SysSuspendCallbackResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for SysSuspendCallbackResponse
impl Eq for SysSuspendCallbackResponse
impl Persistable for SysSuspendCallbackResponse
impl StructuralPartialEq for SysSuspendCallbackResponse